导入 sys
导入 os

sys.path.追加(os.路径.绝对路径(r'G:\grasspy_zwmodules\pysimplegui\zwpysimplegui\src'))

import 快手 as sg      

sg.ChangeLookAndFeel('GreenTan')      

# ------ Menu Definition ------ #      
menu_def = [['File', ['Open', 'Save', 'Exit', 'Properties']],      
            ['Edit', ['Paste', ['Special', 'Normal', ], 'Undo'], ],      
            ['Help', 'About...'], ]      

# ------ Column Definition ------ #      
column1 = [[sg.Text('Column 1', background_color='#F7F3EC', justification='center', size=(10, 1))],      
            [sg.Spin(values=('Spin Box 1', '2', '3'), initial_value='Spin Box 1')],      
            [sg.Spin(values=('Spin Box 1', '2', '3'), initial_value='Spin Box 2')],      
            [sg.Spin(values=('Spin Box 1', '2', '3'), initial_value='Spin Box 3')]]      

layout = [      
    [sg.Menu(menu_def, tearoff=True)],      
    [sg.Text('All graphic widgets in one window!', size=(30, 1), justification='center', font=("Helvetica", 25), relief=sg.RELIEF_RIDGE)],    
    [sg.Text('Here is some text.... and a place to enter text')],      
    [sg.输入框('人民万岁')],      
    [sg.Frame(layout=[      
      [sg.复选框('复选框', 大小=(10,1)),  sg.复选框('又一个复选框!', 默认值=True)],      
      [sg.单选按钮('第一个单选按钮!     ', "RADIO1", 默认值=True, 大小=(10,1)), sg.单选按钮('第二个单选按钮!', "RADIO1")]], title='Options',title_color='red',relief=sg.RELIEF_SUNKEN, tooltip='Use these to set flags')],      
    [sg.Multiline(default_text='This is the default Text should you decide not to type anything', size=(35, 3)),      
        sg.Multiline(default_text='A second multi-line', size=(35, 3))],      
    [sg.组合框(('组合框 1', '组合框 2'), 大小=(20, 1)),      
        sg.Slider(range=(1, 100), orientation='h', size=(34, 20), default_value=85)],      
    [sg.选项菜单(('选项菜单 1', '选项菜单 2', '选项菜单 3'))],      
    [sg.列表框(值选项=('列表框 1', '列表框 2', '列表框 3'), 大小=(30, 3)),      
        sg.Frame('Labelled Group',[[      
        sg.Slider(range=(1, 100), orientation='v', size=(5, 20), default_value=25),      
        sg.Slider(range=(1, 100), orientation='v', size=(5, 20), default_value=75),      
        sg.Slider(range=(1, 100), orientation='v', size=(5, 20), default_value=10),      
        sg.Column(column1, background_color='#F7F3EC')]])],      
    [sg.Text('_'  * 80)],      
    [sg.Text('Choose A Folder', size=(35, 1))],      
    [sg.Text('Your Folder', size=(15, 1), auto_size_text=False, justification='right'),      
        sg.输入框('默认文件夹'), sg.FolderBrowse()],      
    [sg.Submit(tooltip='Click to submit this window'), sg.Cancel()]    
]      


window = sg.Window('Everything bagel', layout, default_element_size=(40, 1), grab_anywhere=False)      

event, values = window.read()      

window.close()    

sg.popup('Title',      
            'The results of the window.',      
            'The button clicked was "{}"'.format(event),      
            'The values are', values)      


导入 sys
导入 os

sys.path.追加(os.路径.绝对路径(r'G:\grasspy_zwmodules\pysimplegui\zwpysimplegui\src'))

导入 快手

快手.更改外观('青褐色')      

菜单定义 = [ ['文件', ['打开', '保存', '退出', '属性']],      
            ['编辑', ['粘贴', ['特殊', '常规'], '撤消']],      
            ['帮助', '关于...'] ]

列1 = [ [快手.标签('列 1', 背景颜色='#F7F3EC', 对齐='居中', 大小=(10, 1))],      
        [快手.旋钮控件(值选项=('旋钮控件 1', '2', '3'), 初始值='旋钮控件 1')],      
        [快手.旋钮控件(值选项=('旋钮控件 1', '2', '3'), 初始值='旋钮控件 2')],      
        [快手.旋钮控件(值选项=('旋钮控件 1', '2', '3'), 初始值='旋钮控件 3')] ]      

布局 = [      
    [快手.菜单(菜单定义)],      
    [快手.标签('一个窗口显示几乎所有图形部件!', 大小=(35, 1), 对齐='居中', 字体=("微软雅黑", 25), 边框样式=快手.山脊C)],    
    [快手.标签('这是一些文字...... 以及输入文字的地方')],      
    [快手.输入框('这是我输入的文字')],      
    [快手.框架(布局=[      
        [快手.复选框('复选框', 大小=(15,1)),  快手.复选框('第二个复选框!', 默认值=真)],      
        [快手.单选按钮('我的第一个单选按钮!', "单选按钮1", 默认值=真, 大小=(15,1)), 快手.单选按钮('我的第二个单选按钮!', "单选按钮1")]],
        标题='选项', 标题颜色='red', 边框样式=快手.凹陷C, 提示='用于设置标志')],      
    [快手.多行文本框(默认文本='这是默认文本, 如果您决定不键入任何东西', 大小=(35, 3)),      
        快手.多行文本框(默认文本='第二个多行文本框', 大小=(35, 3))],      
    [快手.组合框(('组合框 1', '组合框 2'), 大小=(20, 1)),      
        快手.滑块(范围=(1, 100), 方向='水平', 大小=(34, 20), 默认值=85)],      
    [快手.选项菜单(('菜单选项 1', '菜单选项 2', '菜单选项 3'), 大小=(10, 1))],      
    [快手.列表框(值选项=('列表框 1', '列表框 2', '列表框 3'), 大小=(30, 3)),      
        快手.框架('带标签组',[
            [快手.滑块(范围=(1, 100), 方向='垂直', 大小=(5, 20), 默认值=25),      
            快手.滑块(范围=(1, 100), 方向='垂直', 大小=(5, 20), 默认值=75),      
            快手.滑块(范围=(1, 100), 方向='垂直', 大小=(5, 20), 默认值=10),      
            快手.列(列1, 背景颜色='#F7F3EC')] ])],      
    [快手.标签('_'  * 100)],      
    [快手.标签('选择文件夹', 大小=(35, 1))],      
    [快手.标签('您的文件夹', 大小=(15, 1), 大小适应文本=假, 对齐='右'),      
        快手.输入框('默认文件夹'), 快手.文件夹浏览按钮()],      
    [快手.提交按钮(提示='点击提交此窗口'), 快手.取消按钮()]    
]      


窗口 = 快手.窗口类('图形界面元素', 布局, 默认元素大小=(40, 1), 任意地方抓取=假)      

事件, 值 = 窗口.读取()      

窗口.关闭()    

快手.弹窗('标题', '窗口结果', '点击的按钮是 "{}"'.格式化(事件), '值为:', 值)  


导入 sys
导入 os

sys.path.追加(os.路径.绝对路径(r'G:\grasspy_zwmodules\pysimplegui\zwpysimplegui\src'))

导入 快手

布局 = [  [快手.标签('5 - 1 = ')],      
          [快手.单选按钮('1', '答案', 大小=(5,1)), 快手.单选按钮('2', '答案', 大小=(5,1)), 
            快手.单选按钮('3', '答案', 大小=(5,1)), 快手.单选按钮('4', '答案', 大小=(5,1))],      
          [快手.按钮('重做'), 快手.按钮('提交')]  ]      

窗口 = 快手.窗口类('选择题', 布局)

只要 真:                             # 事件循环
    事件, 值 = 窗口.读取() 
    打印(事件, 值)       
    如果 事件 == 空 或 事件 == '提交':  # 退出窗口事件
        跳出      

窗口.关闭()

